@@ -13,13 +13,15 @@ get_group_names.mblogit <- function(model, type, ...) {
 #' @include sanity_model.R
 #' @rdname sanity_model_specific
 #' @export
-sanity_model_specific.mblogit <- function(model, ...) {
-    variables <- insight::find_variables(model, flatten = TRUE)
-    dat <- insight::get_data(model)
-    dat <- dat[, intersect(variables, colnames(dat))]
-    flag <- any(sapply(dat, is.character))
-    if (isTRUE(flag)) {
-        stop("Cannot compute marginal effects for models of class `mblogit` when the data includes character variables. Please convert character variables to factors in the dataset before fitting the model, and call `marginaleffects` again.")
+sanity_model_specific.mblogit <- function(model, calling_function = "marginaleffects", ...) {
+    if (calling_function == "marginaleffects") {
+        variables <- insight::find_variables(model, flatten = TRUE)
+        dat <- insight::get_data(model)
+        dat <- dat[, intersect(variables, colnames(dat))]
+        flag <- any(sapply(dat, is.character))
+        if (isTRUE(flag)) {
+            stop("Cannot compute marginal effects for models of class `mblogit` when the data includes character variables. Please convert character variables to factors in the dataset before fitting the model, and call `marginaleffects` again.")
+        }
     }
 }
 
