@@ -15,7 +15,7 @@ set_coef.hurdle <- function(model, coefs) {
         if (anyNA(idx)) {
             stop("Mismatched coefficients names. Please check the `marginaleffects::`set_coef.hurdle` or `set_coef.zeroinfl` function.")
         }
-        out$coefficients[[lab]] <- stats::setNames(coefs[idx], out$coefficients[[lab]])
+        out$coefficients[[lab]] <- stats::setNames(coefs[idx], names(out$coefficients[[lab]]))
     }
     return(out)
 }
