@@ -4,13 +4,17 @@
 #' @return A warning, an error, or nothing
 #' @rdname sanity_model_specific
 #' @keywords internal
-sanity_model_specific <- function (model, ...) {
+sanity_model_specific <- function (model,
+                                   calling_function = "marginaleffects",
+                                   ...) {
     UseMethod("sanity_model_specific", model)
 }
 
 
 #' @rdname sanity_model_specific
-sanity_model_specific.default <- function(model, ...) {
+sanity_model_specific.default <- function(model,
+                                          calling_function = "marginaleffects",
+                                          ...) {
     dots <- list(...)
     # if (length(dots) > 0) {
     #     warning(sprintf("The following arguments will be ignored: %s. Please refer to the documentation for a list of supported model-specific arguments.", paste(sort(names(dots)), collapse = ", ")))
@@ -62,6 +66,7 @@ sanity_model_supported_class <- function(model) {
                       "rlmerMod",
                       "rq",
                       c("scam", "glm", "lm"),
+                      c("selection", "selection", "list"),
                       "speedglm",
                       "speedlm",
                       "stanreg",
