@@ -1,4 +1,3 @@
-skip_if_not_installed("bife")
 requiet("bife")
 
 test_that("marginaleffects: bife: no validity", {
@@ -16,5 +15,5 @@ test_that("predictions: bife: no validity", {
     dataset <- bife::psid
     mod <- bife(LFP ~ AGE + I(INCH / 1000) + KID1 + KID2 + KID3 | ID, data = dataset)
     pred <- predictions(mod)
-    expect_predictions(pred, n_row = 1, se = FALSE)
+    expect_predictions(pred, n_row = nrow(insight::get_data(mod)))
 })
