@@ -30,6 +30,7 @@ test_that("vs. emmeans vs. margins", {
 
 
 test_that("bug: population-level predictions() when {lmerTest} is loaded", {
+    requiet("lmerTest")
     mod <- suppressMessages(lmer(
       weight ~ 1 + Time + I(Time^2) + Diet + Time:Diet + I(Time^2):Diet + (1 + Time + I(Time^2) | Chick),
       data = ChickWeight))
@@ -39,4 +40,9 @@ test_that("bug: population-level predictions() when {lmerTest} is loaded", {
                                                   Time = 0:21),
                                include_random = FALSE),
                    NA)
+    expect_warning(predictions(mod,
+                               newdata = datagrid(Diet = 1:4,
+                                                  Time = 0:21),
+                               include_random = TRUE),
+                   NA)
 })
