@@ -5,7 +5,9 @@ pred <- predictions(mod)
 test_that("tidy.predictions", {
     requiet("MASS")
     mod1 <- glm(vs ~ hp * mpg, data = mtcars, family = binomial)
-    mod2 <- polr(factor(gear) ~ hp * mpg, data = mtcars)
+    # there used to be an interaction in this polr model, but it produced
+    # negative variances and NaN standard errors
+    mod2 <- polr(factor(gear) ~ hp + mpg, data = mtcars)
     pred1 <- predictions(mod1)
     pred2 <- predictions(mod2, type = "probs")
     ti1 <- tidy(pred1)
